@@ -142,10 +142,6 @@ cleanup() {
 
     stop_inline_spinner 2> /dev/null || true
 
-    if [[ -t 1 ]]; then
-        printf "\r\033[K" >&2 || true
-    fi
-
     cleanup_temp_files
 
     stop_sudo_session
@@ -365,6 +361,7 @@ safe_clean() {
         if should_protect_path "$path"; then
             skip=true
             ((skipped_count++))
+            log_operation "clean" "SKIPPED" "$path" "protected"
         fi
 
         [[ "$skip" == "true" ]] && continue
@@ -372,6 +369,7 @@ safe_clean() {
         if is_path_whitelisted "$path"; then
             skip=true
             ((skipped_count++))
+            log_operation "clean" "SKIPPED" "$path" "whitelist"
         fi
         [[ "$skip" == "true" ]] && continue
         [[ -e "$path" ]] && existing_paths+=("$path")
@@ -381,7 +379,7 @@ safe_clean() {
         stop_section_spinner
     fi
 
-    debug_log "Cleaning: $description (${#existing_paths[@]} items)"
+    debug_log "Cleaning: $description, ${#existing_paths[@]} items"
 
     # Enhanced debug output with risk level and details
     if [[ "${MO_DEBUG:-}" == "1" && ${#existing_paths[@]} -gt 0 ]]; then
@@ -431,6 +429,8 @@ safe_clean() {
         if [[ -t 1 ]]; then MOLE_SPINNER_PREFIX="  " start_inline_spinner "Scanning items..."; fi
     fi
 
+    local cleaning_spinner_started=false
+
     # For larger batches, precompute sizes in parallel for better UX/stat accuracy.
     if [[ ${#existing_paths[@]} -gt 3 ]]; then
         local temp_dir
@@ -522,6 +522,11 @@ safe_clean() {
         fi
 
         # Read results back in original order.
+        # Start spinner for cleaning phase
+        if [[ "$DRY_RUN" != "true" && ${#existing_paths[@]} -gt 0 && -t 1 ]]; then
+            MOLE_SPINNER_PREFIX="  " start_inline_spinner "Cleaning..."
+            cleaning_spinner_started=true
+        fi
         idx=0
         if [[ ${#existing_paths[@]} -gt 0 ]]; then
             for path in "${existing_paths[@]}"; do
@@ -530,12 +535,8 @@ safe_clean() {
                     read -r size count < "$result_file" 2> /dev/null || true
                     local removed=0
                     if [[ "$DRY_RUN" != "true" ]]; then
-                        if [[ -L "$path" ]]; then
-                            rm "$path" 2> /dev/null && removed=1
-                        else
-                            if safe_remove "$path" true; then
-                                removed=1
-                            fi
+                        if safe_remove "$path" true; then
+                            removed=1
                         fi
                     else
                         removed=1
@@ -558,6 +559,11 @@ safe_clean() {
         fi
 
     else
+        # Start spinner for cleaning phase (small batch)
+        if [[ "$DRY_RUN" != "true" && ${#existing_paths[@]} -gt 0 && -t 1 ]]; then
+            MOLE_SPINNER_PREFIX="  " start_inline_spinner "Cleaning..."
+            cleaning_spinner_started=true
+        fi
         local idx=0
         if [[ ${#existing_paths[@]} -gt 0 ]]; then
             for path in "${existing_paths[@]}"; do
@@ -567,12 +573,8 @@ safe_clean() {
 
                 local removed=0
                 if [[ "$DRY_RUN" != "true" ]]; then
-                    if [[ -L "$path" ]]; then
-                        rm "$path" 2> /dev/null && removed=1
-                    else
-                        if safe_remove "$path" true; then
-                            removed=1
-                        fi
+                    if safe_remove "$path" true; then
+                        removed=1
                     fi
                 else
                     removed=1
@@ -594,8 +596,8 @@ safe_clean() {
         fi
     fi
 
-    if [[ "$show_spinner" == "true" ]]; then
-        stop_section_spinner
+    if [[ "$show_spinner" == "true" || "$cleaning_spinner_started" == "true" ]]; then
+        stop_inline_spinner
     fi
 
     local permission_end=${MOLE_PERMISSION_DENIED_COUNT:-0}
@@ -604,7 +606,7 @@ safe_clean() {
         debug_log "Permission denied while cleaning: $description"
     fi
     if [[ $removal_failed_count -gt 0 && "$DRY_RUN" != "true" ]]; then
-        debug_log "Skipped $removal_failed_count items (permission denied or in use) for: $description"
+        debug_log "Skipped $removal_failed_count items, permission denied or in use, for: $description"
     fi
 
     if [[ $removed_any -eq 1 ]]; then
@@ -619,7 +621,7 @@ safe_clean() {
         fi
 
         if [[ "$DRY_RUN" == "true" ]]; then
-            echo -e "  ${YELLOW}${ICON_DRY_RUN}${NC} $label ${YELLOW}($size_human dry)${NC}"
+            echo -e "  ${YELLOW}${ICON_DRY_RUN}${NC} $label${NC}, ${YELLOW}$size_human dry${NC}"
 
             local paths_temp=$(create_temp_file)
 
@@ -670,7 +672,7 @@ safe_clean() {
                 ' | while IFS='|' read -r display_path total_size child_count; do
                     local size_human=$(bytes_to_human "$((total_size * 1024))")
                     if [[ $child_count -gt 1 ]]; then
-                        echo "$display_path  # $size_human ($child_count items)" >> "$EXPORT_LIST_FILE"
+                        echo "$display_path  # $size_human, $child_count items" >> "$EXPORT_LIST_FILE"
                     else
                         echo "$display_path  # $size_human" >> "$EXPORT_LIST_FILE"
                     fi
@@ -679,7 +681,7 @@ safe_clean() {
                 rm -f "$paths_temp"
             fi
         else
-            echo -e "  ${GREEN}${ICON_SUCCESS}${NC} $label ${GREEN}($size_human)${NC}"
+            echo -e "  ${GREEN}${ICON_SUCCESS}${NC} $label${NC}, ${GREEN}$size_human${NC}"
         fi
         ((files_cleaned += total_count))
         ((total_size_cleaned += total_size_kb))
@@ -691,6 +693,10 @@ safe_clean() {
 }
 
 start_cleanup() {
+    # Set current command for operation logging
+    export MOLE_CURRENT_COMMAND="clean"
+    log_operation_session_start "clean"
+
     if [[ -t 1 ]]; then
         printf '\033[2J\033[H'
     fi
@@ -703,7 +709,7 @@ start_cleanup() {
     fi
 
     if [[ "$DRY_RUN" == "true" ]]; then
-        echo -e "${YELLOW}Dry Run Mode${NC} - Preview only, no deletions"
+        echo -e "${YELLOW}Dry Run Mode${NC}, Preview only, no deletions"
         echo ""
         SYSTEM_CLEAN=false
 
@@ -729,7 +735,7 @@ EOF
             echo -e "${GREEN}${ICON_SUCCESS}${NC} Admin access already available"
             echo ""
         else
-            echo -ne "${PURPLE}${ICON_ARROW}${NC} System caches need sudo — ${GREEN}Enter${NC} continue, ${GRAY}Space${NC} skip: "
+            echo -ne "${PURPLE}${ICON_ARROW}${NC} System caches need sudo. ${GREEN}Enter${NC} continue, ${GRAY}Space${NC} skip: "
 
             local choice
             choice=$(read_key)
@@ -766,10 +772,10 @@ EOF
         echo "Running in non-interactive mode"
         if sudo -n true 2> /dev/null; then
             SYSTEM_CLEAN=true
-            echo "  ${ICON_LIST} System-level cleanup enabled (sudo session active)"
+            echo "  ${ICON_LIST} System-level cleanup enabled, sudo session active"
         else
             SYSTEM_CLEAN=false
-            echo "  ${ICON_LIST} System-level cleanup skipped (requires sudo)"
+            echo "  ${ICON_LIST} System-level cleanup skipped, requires sudo"
         fi
         echo "  ${ICON_LIST} User-level cleanup will proceed automatically"
         echo ""
@@ -782,7 +788,7 @@ perform_cleanup() {
     if [[ "${MOLE_TEST_MODE:-0}" == "1" ]]; then
         test_mode_enabled=true
         if [[ "$DRY_RUN" == "true" ]]; then
-            echo -e "${YELLOW}Dry Run Mode${NC} - Preview only, no deletions"
+            echo -e "${YELLOW}Dry Run Mode${NC}, Preview only, no deletions"
             echo ""
         fi
         echo -e "${GREEN}${ICON_LIST}${NC} User app cache"
@@ -964,6 +970,7 @@ perform_cleanup() {
     start_section "Uninstalled app data"
     clean_orphaned_app_data
     clean_orphaned_system_services
+    clean_orphaned_launch_agents
     end_section
 
     # ===== 13. Apple Silicon optimizations =====
@@ -1036,7 +1043,11 @@ perform_cleanup() {
                 local movies
                 movies=$(echo "$freed_gb" | awk '{printf "%.0f", $1/4.5}')
                 if [[ $movies -gt 0 ]]; then
-                    summary_details+=("Equivalent to ~$movies 4K movies of storage.")
+                    if [[ $movies -eq 1 ]]; then
+                        summary_details+=("Equivalent to ~$movies 4K movie of storage.")
+                    else
+                        summary_details+=("Equivalent to ~$movies 4K movies of storage.")
+                    fi
                 fi
             fi
 
@@ -1046,7 +1057,7 @@ perform_cleanup() {
     else
         summary_status="info"
         if [[ "$DRY_RUN" == "true" ]]; then
-            summary_details+=("No significant reclaimable space detected (system already clean).")
+            summary_details+=("No significant reclaimable space detected, system already clean.")
         else
             summary_details+=("System was already clean; no additional space freed.")
         fi
@@ -1057,6 +1068,9 @@ perform_cleanup() {
         set -e
     fi
 
+    # Log session end with summary
+    log_operation_session_end "clean" "$files_cleaned" "$total_size_cleaned"
+
     print_summary_block "$summary_heading" "${summary_details[@]}"
     printf '\n'
 }
@@ -1064,6 +1078,10 @@ perform_cleanup() {
 main() {
     for arg in "$@"; do
         case "$arg" in
+            "--help" | "-h")
+                show_clean_help
+                exit 0
+                ;;
             "--debug")
                 export MO_DEBUG=1
                 ;;
