@@ -5,13 +5,11 @@ package main
 import (
 	"context"
 	"fmt"
-	"io/fs"
 	"os"
 	"os/exec"
 	"path/filepath"
 	"slices"
 	"sort"
-	"strings"
 	"sync/atomic"
 	"time"
 
@@ -63,8 +61,10 @@ type historyEntry struct {
 }
 
 type scanResultMsg struct {
+	path   string
 	result scanResult
 	err    error
+	stale  bool
 }
 
 type overviewSizeMsg struct {
@@ -231,40 +231,9 @@ func createOverviewEntries() []dirEntry {
 		dirEntry{Name: "System Library", Path: "/Library", IsDir: true, Size: -1},
 	)
 
-	// Include Volumes only when real mounts exist.
-	if hasUsefulVolumeMounts("/Volumes") {
-		entries = append(entries, dirEntry{Name: "Volumes", Path: "/Volumes", IsDir: true, Size: -1})
-	}
-
 	return entries
 }
 
-func hasUsefulVolumeMounts(path string) bool {
-	entries, err := os.ReadDir(path)
-	if err != nil {
-		return false
-	}
-
-	for _, entry := range entries {
-		name := entry.Name()
-		if strings.HasPrefix(name, ".") {
-			continue
-		}
-
-		info, err := os.Lstat(filepath.Join(path, name))
-		if err != nil {
-			continue
-		}
-		if info.Mode()&fs.ModeSymlink != 0 {
-			continue // Ignore the synthetic MacintoshHD link
-		}
-		if info.IsDir() {
-			return true
-		}
-	}
-	return false
-}
-
 func (m *model) hydrateOverviewEntries() {
 	m.entries = createOverviewEntries()
 	if m.overviewSizeCache == nil {
@@ -332,9 +301,9 @@ func (m *model) scheduleOverviewScans() tea.Cmd {
 	if len(pendingIndices) > 0 {
 		firstEntry := m.entries[pendingIndices[0]]
 		if len(pendingIndices) == 1 {
-			m.status = fmt.Sprintf("Scanning %s... (%d left)", firstEntry.Name, remaining)
+			m.status = fmt.Sprintf("Scanning %s..., %d left", firstEntry.Name, remaining)
 		} else {
-			m.status = fmt.Sprintf("Scanning %d directories... (%d left)", len(pendingIndices), remaining)
+			m.status = fmt.Sprintf("Scanning %d directories..., %d left", len(pendingIndices), remaining)
 		}
 	}
 
@@ -369,9 +338,19 @@ func (m model) scanCmd(path string) tea.Cmd {
 				Entries:    cached.Entries,
 				LargeFiles: cached.LargeFiles,
 				TotalSize:  cached.TotalSize,
-				TotalFiles: 0, // Cache doesn't store file count currently, minor UI limitation
+				TotalFiles: cached.TotalFiles,
 			}
-			return scanResultMsg{result: result, err: nil}
+			return scanResultMsg{path: path, result: result, err: nil}
+		}
+
+		if stale, err := loadStaleCacheFromDisk(path); err == nil {
+			result := scanResult{
+				Entries:    stale.Entries,
+				LargeFiles: stale.LargeFiles,
+				TotalSize:  stale.TotalSize,
+				TotalFiles: stale.TotalFiles,
+			}
+			return scanResultMsg{path: path, result: result, err: nil, stale: true}
 		}
 
 		v, err, _ := scanGroup.Do(path, func() (any, error) {
@@ -379,7 +358,7 @@ func (m model) scanCmd(path string) tea.Cmd {
 		})
 
 		if err != nil {
-			return scanResultMsg{err: err}
+			return scanResultMsg{path: path, err: err}
 		}
 
 		result := v.(scanResult)
@@ -390,7 +369,28 @@ func (m model) scanCmd(path string) tea.Cmd {
 			}
 		}(path, result)
 
-		return scanResultMsg{result: result, err: nil}
+		return scanResultMsg{path: path, result: result, err: nil}
+	}
+}
+
+func (m model) scanFreshCmd(path string) tea.Cmd {
+	return func() tea.Msg {
+		v, err, _ := scanGroup.Do(path, func() (any, error) {
+			return scanPathConcurrent(path, m.filesScanned, m.dirsScanned, m.bytesScanned, m.currentPath)
+		})
+
+		if err != nil {
+			return scanResultMsg{path: path, err: err}
+		}
+
+		result := v.(scanResult)
+		go func(p string, r scanResult) {
+			if err := saveCacheToDisk(p, r); err != nil {
+				_ = err
+			}
+		}(path, result)
+
+		return scanResultMsg{path: path, result: result}
 	}
 }
 
@@ -442,6 +442,9 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 		}
 		return m, nil
 	case scanResultMsg:
+		if msg.path != "" && msg.path != m.path {
+			return m, nil
+		}
 		m.scanning = false
 		if msg.err != nil {
 			m.status = fmt.Sprintf("Scan failed: %v", msg.err)
@@ -457,7 +460,6 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 		m.largeFiles = msg.result.LargeFiles
 		m.totalSize = msg.result.TotalSize
 		m.totalFiles = msg.result.TotalFiles
-		m.status = fmt.Sprintf("Scanned %s", humanizeBytes(m.totalSize))
 		m.clampEntrySelection()
 		m.clampLargeSelection()
 		m.cache[m.path] = cacheSnapshot(m)
@@ -470,6 +472,23 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 				_ = storeOverviewSize(path, size)
 			}(m.path, m.totalSize)
 		}
+
+		if msg.stale {
+			m.status = fmt.Sprintf("Loaded cached data for %s, refreshing...", displayPath(m.path))
+			m.scanning = true
+			if m.totalFiles > 0 {
+				m.lastTotalFiles = m.totalFiles
+			}
+			atomic.StoreInt64(m.filesScanned, 0)
+			atomic.StoreInt64(m.dirsScanned, 0)
+			atomic.StoreInt64(m.bytesScanned, 0)
+			if m.currentPath != nil {
+				m.currentPath.Store("")
+			}
+			return m, tea.Batch(m.scanFreshCmd(m.path), tickCmd())
+		}
+
+		m.status = fmt.Sprintf("Scanned %s", humanizeBytes(m.totalSize))
 		return m, nil
 	case overviewSizeMsg:
 		delete(m.overviewScanningSet, msg.Path)
@@ -736,7 +755,7 @@ func (m model) updateKey(msg tea.KeyMsg) (tea.Model, tea.Cmd) {
 				if len(m.largeMultiSelected) > 0 {
 					count := len(m.largeMultiSelected)
 					if count > maxBatchOpen {
-						m.status = fmt.Sprintf("Too many items to open (max %d, selected %d)", maxBatchOpen, count)
+						m.status = fmt.Sprintf("Too many items to open, max %d, selected %d", maxBatchOpen, count)
 						return m, nil
 					}
 					for path := range m.largeMultiSelected {
@@ -761,7 +780,7 @@ func (m model) updateKey(msg tea.KeyMsg) (tea.Model, tea.Cmd) {
 			if len(m.multiSelected) > 0 {
 				count := len(m.multiSelected)
 				if count > maxBatchOpen {
-					m.status = fmt.Sprintf("Too many items to open (max %d, selected %d)", maxBatchOpen, count)
+					m.status = fmt.Sprintf("Too many items to open, max %d, selected %d", maxBatchOpen, count)
 					return m, nil
 				}
 				for path := range m.multiSelected {
@@ -790,7 +809,7 @@ func (m model) updateKey(msg tea.KeyMsg) (tea.Model, tea.Cmd) {
 				if len(m.largeMultiSelected) > 0 {
 					count := len(m.largeMultiSelected)
 					if count > maxBatchReveal {
-						m.status = fmt.Sprintf("Too many items to reveal (max %d, selected %d)", maxBatchReveal, count)
+						m.status = fmt.Sprintf("Too many items to reveal, max %d, selected %d", maxBatchReveal, count)
 						return m, nil
 					}
 					for path := range m.largeMultiSelected {
@@ -815,7 +834,7 @@ func (m model) updateKey(msg tea.KeyMsg) (tea.Model, tea.Cmd) {
 			if len(m.multiSelected) > 0 {
 				count := len(m.multiSelected)
 				if count > maxBatchReveal {
-					m.status = fmt.Sprintf("Too many items to reveal (max %d, selected %d)", maxBatchReveal, count)
+					m.status = fmt.Sprintf("Too many items to reveal, max %d, selected %d", maxBatchReveal, count)
 					return m, nil
 				}
 				for path := range m.multiSelected {
@@ -860,7 +879,7 @@ func (m model) updateKey(msg tea.KeyMsg) (tea.Model, tea.Cmd) {
 							}
 						}
 					}
-					m.status = fmt.Sprintf("%d selected (%s)", count, humanizeBytes(totalSize))
+					m.status = fmt.Sprintf("%d selected, %s", count, humanizeBytes(totalSize))
 				} else {
 					m.status = fmt.Sprintf("Scanned %s", humanizeBytes(m.totalSize))
 				}
@@ -886,7 +905,7 @@ func (m model) updateKey(msg tea.KeyMsg) (tea.Model, tea.Cmd) {
 						}
 					}
 				}
-				m.status = fmt.Sprintf("%d selected (%s)", count, humanizeBytes(totalSize))
+				m.status = fmt.Sprintf("%d selected, %s", count, humanizeBytes(totalSize))
 			} else {
 				m.status = fmt.Sprintf("Scanned %s", humanizeBytes(m.totalSize))
 			}
@@ -1011,7 +1030,7 @@ func (m model) enterSelectedDir() (tea.Model, tea.Cmd) {
 		}
 		return m, tea.Batch(m.scanCmd(m.path), tickCmd())
 	}
-	m.status = fmt.Sprintf("File: %s (%s)", selected.Name, humanizeBytes(selected.Size))
+	m.status = fmt.Sprintf("File: %s, %s", selected.Name, humanizeBytes(selected.Size))
 	return m, nil
 }
 
