@@ -145,7 +145,7 @@ func renderHeader(m MetricsSnapshot, errMsg string, animFrame int, termWidth int
 		cpuInfo := m.Hardware.CPUModel
 		// Append GPU core count when available.
 		if len(m.GPU) > 0 && m.GPU[0].CoreCount > 0 {
-			cpuInfo += fmt.Sprintf(" (%dGPU)", m.GPU[0].CoreCount)
+			cpuInfo += fmt.Sprintf(", %dGPU", m.GPU[0].CoreCount)
 		}
 		infoParts = append(infoParts, cpuInfo)
 	}
@@ -218,7 +218,7 @@ func renderCPUCard(cpu CPUStatus, thermal ThermalStatus) cardData {
 	lines = append(lines, fmt.Sprintf("Total  %s  %s", usageBar, headerText))
 
 	if cpu.PerCoreEstimated {
-		lines = append(lines, subtleStyle.Render("Per-core data unavailable (using averaged load)"))
+		lines = append(lines, subtleStyle.Render("Per-core data unavailable, using averaged load"))
 	} else if len(cpu.PerCore) > 0 {
 		type coreUsage struct {
 			idx int
@@ -239,10 +239,10 @@ func renderCPUCard(cpu CPUStatus, thermal ThermalStatus) cardData {
 
 	// Load line at the end
 	if cpu.PCoreCount > 0 && cpu.ECoreCount > 0 {
-		lines = append(lines, fmt.Sprintf("Load   %.2f / %.2f / %.2f (%dP+%dE)",
+		lines = append(lines, fmt.Sprintf("Load   %.2f / %.2f / %.2f, %dP+%dE",
 			cpu.Load1, cpu.Load5, cpu.Load15, cpu.PCoreCount, cpu.ECoreCount))
 	} else {
-		lines = append(lines, fmt.Sprintf("Load   %.2f / %.2f / %.2f (%d cores)",
+		lines = append(lines, fmt.Sprintf("Load   %.2f / %.2f / %.2f, %d cores",
 			cpu.Load1, cpu.Load5, cpu.Load15, cpu.LogicalCPU))
 	}
 
@@ -270,7 +270,7 @@ func renderMemoryCard(mem MemoryStatus) cardData {
 		if mem.SwapTotal > 0 {
 			swapPercent = (float64(mem.SwapUsed) / float64(mem.SwapTotal)) * 100.0
 		}
-		swapText := fmt.Sprintf("(%s/%s)", humanBytesCompact(mem.SwapUsed), humanBytesCompact(mem.SwapTotal))
+		swapText := fmt.Sprintf("%s/%s", humanBytesCompact(mem.SwapUsed), humanBytesCompact(mem.SwapTotal))
 		lines = append(lines, fmt.Sprintf("Swap   %s  %5.1f%% %s", progressBar(swapPercent), swapPercent, swapText))
 
 		lines = append(lines, fmt.Sprintf("Total  %s / %s", humanBytes(mem.Used), humanBytes(mem.Total)))
@@ -361,7 +361,7 @@ func formatDiskLine(label string, d DiskStatus) string {
 	bar := progressBar(d.UsedPercent)
 	used := humanBytesShort(d.Used)
 	total := humanBytesShort(d.Total)
-	return fmt.Sprintf("%-6s %s  %5.1f%% (%s/%s)", label, bar, d.UsedPercent, used, total)
+	return fmt.Sprintf("%-6s %s  %5.1f%%, %s/%s", label, bar, d.UsedPercent, used, total)
 }
 
 func ioBar(rate float64) string {
@@ -763,7 +763,7 @@ func renderTwoColumns(cards []cardData, width int) string {
 		if i+1 < len(cards) {
 			right = renderCard(cards[i+1], cw, 0)
 		}
-		targetHeight := maxInt(lipgloss.Height(left), lipgloss.Height(right))
+		targetHeight := max(lipgloss.Height(left), lipgloss.Height(right))
 		left = renderCard(cards[i], cw, targetHeight)
 		if right != "" {
 			right = renderCard(cards[i+1], cw, targetHeight)
@@ -782,10 +782,3 @@ func renderTwoColumns(cards []cardData, width int) string {
 	}
 	return lipgloss.JoinVertical(lipgloss.Left, spacedRows...)
 }
-
-func maxInt(a, b int) int {
-	if a > b {
-		return a
-	}
-	return b
-}
