@@ -1,6 +1,8 @@
 #!/bin/bash
 # Application Data Cleanup Module
 set -euo pipefail
+
+readonly ORPHAN_AGE_THRESHOLD=${ORPHAN_AGE_THRESHOLD:-${MOLE_ORPHAN_AGE_DAYS:-60}}
 # Args: $1=target_dir, $2=label
 clean_ds_store_tree() {
     local target="$1"
@@ -46,9 +48,9 @@ clean_ds_store_tree() {
         local size_human
         size_human=$(bytes_to_human "$total_bytes")
         if [[ "$DRY_RUN" == "true" ]]; then
-            echo -e "  ${YELLOW}${ICON_DRY_RUN}${NC} $label ${YELLOW}($file_count files, $size_human dry)${NC}"
+            echo -e "  ${YELLOW}${ICON_DRY_RUN}${NC} $label${NC}, ${YELLOW}$file_count files, $size_human dry${NC}"
         else
-            echo -e "  ${GREEN}${ICON_SUCCESS}${NC} $label ${GREEN}($file_count files, $size_human)${NC}"
+            echo -e "  ${GREEN}${ICON_SUCCESS}${NC} $label${NC}, ${GREEN}$file_count files, $size_human${NC}"
         fi
         local size_kb=$(((total_bytes + 1023) / 1024))
         ((files_cleaned += file_count))
@@ -70,7 +72,7 @@ scan_installed_apps() {
         current_time=$(get_epoch_seconds)
         local age=$((current_time - cache_mtime))
         if [[ $age -lt $cache_age_seconds ]]; then
-            debug_log "Using cached app list (age: ${age}s)"
+            debug_log "Using cached app list, age: ${age}s"
             if [[ -r "$cache_file" ]] && [[ -s "$cache_file" ]]; then
                 if cat "$cache_file" > "$installed_bundles" 2> /dev/null; then
                     return 0
@@ -82,7 +84,7 @@ scan_installed_apps() {
             fi
         fi
     fi
-    debug_log "Scanning installed applications (cache expired or missing)"
+    debug_log "Scanning installed applications, cache expired or missing"
     local -a app_dirs=(
         "/Applications"
         "/System/Applications"
@@ -282,9 +284,21 @@ clean_orphaned_app_data() {
             file_patterns+=("$base_path/$pat")
         done
         if [[ ${#file_patterns[@]} -gt 0 ]]; then
+            local _nullglob_state
+            _nullglob_state=$(shopt -p nullglob || true)
+            shopt -s nullglob
             for item_path in "${file_patterns[@]}"; do
                 local iteration_count=0
-                for match in $item_path; do
+                local old_ifs=$IFS
+                IFS=$'\n'
+                local -a matches=()
+                # shellcheck disable=SC2206
+                matches=($item_path)
+                IFS=$old_ifs
+                if [[ ${#matches[@]} -eq 0 ]]; then
+                    continue
+                fi
+                for match in "${matches[@]}"; do
                     [[ -e "$match" ]] || continue
                     ((iteration_count++))
                     if [[ $iteration_count -gt $MOLE_MAX_ORPHAN_ITERATIONS ]]; then
@@ -299,18 +313,20 @@ clean_orphaned_app_data() {
                         if [[ -z "$size_kb" || "$size_kb" == "0" ]]; then
                             continue
                         fi
-                        safe_clean "$match" "Orphaned $label: $bundle_id"
-                        ((orphaned_count++))
-                        ((total_orphaned_kb += size_kb))
+                        if safe_clean "$match" "Orphaned $label: $bundle_id"; then
+                            ((orphaned_count++))
+                            ((total_orphaned_kb += size_kb))
+                        fi
                     fi
                 done
             done
+            eval "$_nullglob_state"
         fi
     done
     stop_section_spinner
     if [[ $orphaned_count -gt 0 ]]; then
         local orphaned_mb=$(echo "$total_orphaned_kb" | awk '{printf "%.1f", $1/1024}')
-        echo "  ${GREEN}${ICON_SUCCESS}${NC} Cleaned $orphaned_count items (~${orphaned_mb}MB)"
+        echo "  ${GREEN}${ICON_SUCCESS}${NC} Cleaned $orphaned_count items, about ${orphaned_mb}MB"
         note_activity
     fi
     rm -f "$installed_bundles"
@@ -413,7 +429,7 @@ clean_orphaned_system_services() {
                     fi
                     orphaned_files+=("$plist")
                     local size_kb
-                    size_kb=$(sudo du -sk "$plist" 2> /dev/null | awk '{print $1}' || echo "0")
+                    size_kb=$(sudo du -skP "$plist" 2> /dev/null | awk '{print $1}' || echo "0")
                     ((total_orphaned_kb += size_kb))
                     ((orphaned_count++))
                     break
@@ -444,7 +460,7 @@ clean_orphaned_system_services() {
                     fi
                     orphaned_files+=("$plist")
                     local size_kb
-                    size_kb=$(sudo du -sk "$plist" 2> /dev/null | awk '{print $1}' || echo "0")
+                    size_kb=$(sudo du -skP "$plist" 2> /dev/null | awk '{print $1}' || echo "0")
                     ((total_orphaned_kb += size_kb))
                     ((orphaned_count++))
                     break
@@ -474,7 +490,7 @@ clean_orphaned_system_services() {
                     fi
                     orphaned_files+=("$helper")
                     local size_kb
-                    size_kb=$(sudo du -sk "$helper" 2> /dev/null | awk '{print $1}' || echo "0")
+                    size_kb=$(sudo du -skP "$helper" 2> /dev/null | awk '{print $1}' || echo "0")
                     ((total_orphaned_kb += size_kb))
                     ((orphaned_count++))
                     break
@@ -500,7 +516,7 @@ clean_orphaned_system_services() {
                 if [[ "$orphan_file" == *.plist ]]; then
                     sudo launchctl unload "$orphan_file" 2> /dev/null || true
                 fi
-                if sudo rm -f "$orphan_file" 2> /dev/null; then
+                if safe_sudo_remove "$orphan_file"; then
                     debug_log "Removed orphaned service: $orphan_file"
                 fi
             fi
@@ -512,8 +528,202 @@ clean_orphaned_system_services() {
         else
             orphaned_kb_display="${total_orphaned_kb}KB"
         fi
-        echo -e "  ${GREEN}${ICON_SUCCESS}${NC} Cleaned $orphaned_count orphaned services (~$orphaned_kb_display)"
+        echo -e "  ${GREEN}${ICON_SUCCESS}${NC} Cleaned $orphaned_count orphaned services, about $orphaned_kb_display"
         note_activity
     fi
 
 }
+
+# ============================================================================
+# Orphaned LaunchAgent/LaunchDaemon Cleanup (Generic Detection)
+# ============================================================================
+
+# Extract program path from plist (supports both ProgramArguments and Program)
+_extract_program_path() {
+    local plist="$1"
+    local program=""
+
+    program=$(plutil -extract ProgramArguments.0 raw "$plist" 2> /dev/null)
+    if [[ -z "$program" ]]; then
+        program=$(plutil -extract Program raw "$plist" 2> /dev/null)
+    fi
+
+    echo "$program"
+}
+
+# Extract associated bundle identifier from plist
+_extract_associated_bundle() {
+    local plist="$1"
+    local associated=""
+
+    # Try array format first
+    associated=$(plutil -extract AssociatedBundleIdentifiers.0 raw "$plist" 2> /dev/null)
+    if [[ -z "$associated" ]] || [[ "$associated" == "1" ]]; then
+        # Try string format
+        associated=$(plutil -extract AssociatedBundleIdentifiers raw "$plist" 2> /dev/null)
+        # Filter out dict/array markers
+        if [[ "$associated" == "{"* ]] || [[ "$associated" == "["* ]]; then
+            associated=""
+        fi
+    fi
+
+    echo "$associated"
+}
+
+# Check if a LaunchAgent/LaunchDaemon is orphaned using multi-layer verification
+# Returns 0 if orphaned, 1 if not orphaned
+is_launch_item_orphaned() {
+    local plist="$1"
+
+    # Layer 1: Check if program path exists
+    local program=$(_extract_program_path "$plist")
+
+    # No program path - skip (not a standard launch item)
+    [[ -z "$program" ]] && return 1
+
+    # Program exists -> not orphaned
+    [[ -e "$program" ]] && return 1
+
+    # Layer 2: Check AssociatedBundleIdentifiers
+    local associated=$(_extract_associated_bundle "$plist")
+    if [[ -n "$associated" ]]; then
+        # Check if associated app exists via mdfind
+        if run_with_timeout 2 mdfind "kMDItemCFBundleIdentifier == '$associated'" 2> /dev/null | head -1 | grep -q .; then
+            return 1 # Associated app found -> not orphaned
+        fi
+
+        # Extract vendor name from bundle ID (com.vendor.app -> vendor)
+        local vendor=$(echo "$associated" | cut -d'.' -f2)
+        if [[ -n "$vendor" ]] && [[ ${#vendor} -ge 3 ]]; then
+            # Check if any app from this vendor exists
+            if find /Applications ~/Applications -maxdepth 2 -iname "*${vendor}*" -type d 2> /dev/null | grep -iq "\.app"; then
+                return 1 # Vendor app exists -> not orphaned
+            fi
+        fi
+    fi
+
+    # Layer 3: Check Application Support directory activity
+    if [[ "$program" =~ /Library/Application\ Support/([^/]+)/ ]]; then
+        local app_support_name="${BASH_REMATCH[1]}"
+
+        # Check both user and system Application Support
+        for base in "$HOME/Library/Application Support" "/Library/Application Support"; do
+            local support_path="$base/$app_support_name"
+            if [[ -d "$support_path" ]]; then
+                # Check if there are files modified in last 7 days (active usage)
+                local recent_file=$(find "$support_path" -type f -mtime -7 2> /dev/null | head -1)
+                if [[ -n "$recent_file" ]]; then
+                    return 1 # Active Application Support -> not orphaned
+                fi
+            fi
+        done
+    fi
+
+    # Layer 4: Check if app name from program path exists
+    if [[ "$program" =~ /Applications/([^/]+)\.app/ ]]; then
+        local app_name="${BASH_REMATCH[1]}"
+        # Look for apps with similar names (case-insensitive)
+        if find /Applications ~/Applications -maxdepth 2 -iname "*${app_name}*" -type d 2> /dev/null | grep -iq "\.app"; then
+            return 1 # Similar app exists -> not orphaned
+        fi
+    fi
+
+    # Layer 5: PrivilegedHelper special handling
+    if [[ "$program" =~ ^/Library/PrivilegedHelperTools/ ]]; then
+        local filename=$(basename "$plist")
+        local bundle_id="${filename%.plist}"
+
+        # Extract app hint from bundle ID (com.vendor.app.helper -> vendor)
+        local app_hint=$(echo "$bundle_id" | sed 's/com\.//; s/\..*helper.*//')
+
+        if [[ -n "$app_hint" ]] && [[ ${#app_hint} -ge 3 ]]; then
+            # Look for main app
+            if find /Applications ~/Applications -maxdepth 2 -iname "*${app_hint}*" -type d 2> /dev/null | grep -iq "\.app"; then
+                return 1 # Helper's main app exists -> not orphaned
+            fi
+        fi
+    fi
+
+    # All checks failed -> likely orphaned
+    return 0
+}
+
+# Clean orphaned user-level LaunchAgents
+# Only processes ~/Library/LaunchAgents (safer than system-level)
+clean_orphaned_launch_agents() {
+    local launch_agents_dir="$HOME/Library/LaunchAgents"
+
+    [[ ! -d "$launch_agents_dir" ]] && return 0
+
+    start_section_spinner "Scanning orphaned launch agents..."
+
+    local -a orphaned_items=()
+    local total_orphaned_kb=0
+
+    # Scan user LaunchAgents
+    while IFS= read -r -d '' plist; do
+        local filename=$(basename "$plist")
+
+        # Skip Apple's LaunchAgents
+        [[ "$filename" == com.apple.* ]] && continue
+
+        local bundle_id="${filename%.plist}"
+
+        # Check if orphaned using multi-layer verification
+        if is_launch_item_orphaned "$plist"; then
+            local size_kb=$(get_path_size_kb "$plist")
+            orphaned_items+=("$bundle_id|$plist")
+            ((total_orphaned_kb += size_kb))
+        fi
+    done < <(find "$launch_agents_dir" -maxdepth 1 -name "*.plist" -print0 2> /dev/null)
+
+    stop_section_spinner
+
+    local orphaned_count=${#orphaned_items[@]}
+
+    if [[ $orphaned_count -eq 0 ]]; then
+        return 0
+    fi
+
+    # Clean the orphaned items automatically
+    local removed_count=0
+    local dry_run_count=0
+    local is_dry_run=false
+    if [[ "${MOLE_DRY_RUN:-0}" == "1" ]]; then
+        is_dry_run=true
+    fi
+    for item in "${orphaned_items[@]}"; do
+        IFS='|' read -r bundle_id plist_path <<< "$item"
+
+        if [[ "$is_dry_run" == "true" ]]; then
+            ((dry_run_count++))
+            log_operation "clean" "DRY_RUN" "$plist_path" "orphaned launch agent"
+            continue
+        fi
+
+        # Try to unload first (if currently loaded)
+        launchctl unload "$plist_path" 2> /dev/null || true
+
+        # Remove the plist file
+        if safe_remove "$plist_path" false; then
+            ((removed_count++))
+            log_operation "clean" "REMOVED" "$plist_path" "orphaned launch agent"
+        else
+            log_operation "clean" "FAILED" "$plist_path" "permission denied"
+        fi
+    done
+
+    if [[ "$is_dry_run" == "true" ]]; then
+        if [[ $dry_run_count -gt 0 ]]; then
+            local cleaned_mb=$(echo "$total_orphaned_kb" | awk '{printf "%.1f", $1/1024}')
+            echo "  ${YELLOW}${ICON_DRY_RUN}${NC} Would remove $dry_run_count orphaned launch agent(s), ${cleaned_mb}MB"
+            note_activity
+        fi
+    else
+        if [[ $removed_count -gt 0 ]]; then
+            local cleaned_mb=$(echo "$total_orphaned_kb" | awk '{printf "%.1f", $1/1024}')
+            echo "  ${GREEN}${ICON_SUCCESS}${NC} Removed $removed_count orphaned launch agent(s), ${cleaned_mb}MB"
+            note_activity
+        fi
+    fi
+}
