@@ -7,8 +7,33 @@ clean_user_essentials() {
     stop_section_spinner
 
     safe_clean ~/Library/Logs/* "User app logs"
+
     if ! is_path_whitelisted "$HOME/.Trash"; then
-        safe_clean ~/.Trash/* "Trash"
+        local trash_count
+        trash_count=$(osascript -e 'tell application "Finder" to count items in trash' 2> /dev/null || echo "0")
+        [[ "$trash_count" =~ ^[0-9]+$ ]] || trash_count="0"
+
+        if [[ "$DRY_RUN" == "true" ]]; then
+            [[ $trash_count -gt 0 ]] && echo -e "  ${YELLOW}${ICON_DRY_RUN}${NC} Trash · would empty, $trash_count items" || echo -e "  ${GREEN}${ICON_SUCCESS}${NC} Trash · already empty"
+        elif [[ $trash_count -gt 0 ]]; then
+            if osascript -e 'tell application "Finder" to empty trash' > /dev/null 2>&1; then
+                echo -e "  ${GREEN}${ICON_SUCCESS}${NC} Trash · emptied, $trash_count items"
+                note_activity
+            else
+                local cleaned_count=0
+                while IFS= read -r -d '' item; do
+                    if safe_remove "$item" true; then
+                        ((cleaned_count++))
+                    fi
+                done < <(command find "$HOME/.Trash" -mindepth 1 -maxdepth 1 -print0 2> /dev/null || true)
+                if [[ $cleaned_count -gt 0 ]]; then
+                    echo -e "  ${GREEN}${ICON_SUCCESS}${NC} Trash · emptied, $cleaned_count items"
+                    note_activity
+                fi
+            fi
+        else
+            echo -e "  ${GREEN}${ICON_SUCCESS}${NC} Trash · already empty"
+        fi
     fi
 }
 
@@ -81,9 +106,9 @@ clean_chrome_old_versions() {
         local size_human
         size_human=$(bytes_to_human "$((total_size * 1024))")
         if [[ "$DRY_RUN" == "true" ]]; then
-            echo -e "  ${YELLOW}${ICON_DRY_RUN}${NC} Chrome old versions ${YELLOW}(${cleaned_count} dirs, $size_human dry)${NC}"
+            echo -e "  ${YELLOW}${ICON_DRY_RUN}${NC} Chrome old versions${NC}, ${YELLOW}${cleaned_count} dirs, $size_human dry${NC}"
         else
-            echo -e "  ${GREEN}${ICON_SUCCESS}${NC} Chrome old versions ${GREEN}(${cleaned_count} dirs, $size_human)${NC}"
+            echo -e "  ${GREEN}${ICON_SUCCESS}${NC} Chrome old versions${NC}, ${GREEN}${cleaned_count} dirs, $size_human${NC}"
         fi
         ((files_cleaned += cleaned_count))
         ((total_size_cleaned += total_size))
@@ -94,10 +119,16 @@ clean_chrome_old_versions() {
 
 # Remove old Microsoft Edge versions while keeping Current.
 clean_edge_old_versions() {
-    local -a app_paths=(
-        "/Applications/Microsoft Edge.app"
-        "$HOME/Applications/Microsoft Edge.app"
-    )
+    # Allow override for testing
+    local -a app_paths
+    if [[ -n "${MOLE_EDGE_APP_PATHS:-}" ]]; then
+        IFS=':' read -ra app_paths <<< "$MOLE_EDGE_APP_PATHS"
+    else
+        app_paths=(
+            "/Applications/Microsoft Edge.app"
+            "$HOME/Applications/Microsoft Edge.app"
+        )
+    fi
 
     # Match the exact Edge process name to avoid false positives (e.g., Microsoft Teams)
     if pgrep -x "Microsoft Edge" > /dev/null 2>&1; then
@@ -161,9 +192,9 @@ clean_edge_old_versions() {
         local size_human
         size_human=$(bytes_to_human "$((total_size * 1024))")
         if [[ "$DRY_RUN" == "true" ]]; then
-            echo -e "  ${YELLOW}${ICON_DRY_RUN}${NC} Edge old versions ${YELLOW}(${cleaned_count} dirs, $size_human dry)${NC}"
+            echo -e "  ${YELLOW}${ICON_DRY_RUN}${NC} Edge old versions${NC}, ${YELLOW}${cleaned_count} dirs, $size_human dry${NC}"
         else
-            echo -e "  ${GREEN}${ICON_SUCCESS}${NC} Edge old versions ${GREEN}(${cleaned_count} dirs, $size_human)${NC}"
+            echo -e "  ${GREEN}${ICON_SUCCESS}${NC} Edge old versions${NC}, ${GREEN}${cleaned_count} dirs, $size_human${NC}"
         fi
         ((files_cleaned += cleaned_count))
         ((total_size_cleaned += total_size))
@@ -223,9 +254,9 @@ clean_edge_updater_old_versions() {
         local size_human
         size_human=$(bytes_to_human "$((total_size * 1024))")
         if [[ "$DRY_RUN" == "true" ]]; then
-            echo -e "  ${YELLOW}${ICON_DRY_RUN}${NC} Edge updater old versions ${YELLOW}(${cleaned_count} dirs, $size_human dry)${NC}"
+            echo -e "  ${YELLOW}${ICON_DRY_RUN}${NC} Edge updater old versions${NC}, ${YELLOW}${cleaned_count} dirs, $size_human dry${NC}"
         else
-            echo -e "  ${GREEN}${ICON_SUCCESS}${NC} Edge updater old versions ${GREEN}(${cleaned_count} dirs, $size_human)${NC}"
+            echo -e "  ${GREEN}${ICON_SUCCESS}${NC} Edge updater old versions${NC}, ${GREEN}${cleaned_count} dirs, $size_human${NC}"
         fi
         ((files_cleaned += cleaned_count))
         ((total_size_cleaned += total_size))
@@ -263,12 +294,12 @@ scan_external_volumes() {
     local network_count=${#network_volumes[@]}
     if [[ $volume_count -eq 0 ]]; then
         if [[ $network_count -gt 0 ]]; then
-            echo -e "  ${GRAY}${ICON_LIST}${NC} External volumes (${network_count} network volume(s) skipped)"
+            echo -e "  ${GRAY}${ICON_LIST}${NC} External volumes, ${network_count} network volumes skipped"
             note_activity
         fi
         return 0
     fi
-    start_section_spinner "Scanning $volume_count external volume(s)..."
+    start_section_spinner "Scanning $volume_count external volumes..."
     for volume in "${candidate_volumes[@]}"; do
         [[ -d "$volume" && -r "$volume" ]] || continue
         local volume_trash="$volume/.Trashes"
@@ -278,7 +309,7 @@ scan_external_volumes() {
             done < <(command find "$volume_trash" -mindepth 1 -maxdepth 1 -print0 2> /dev/null || true)
         fi
         if [[ "$PROTECT_FINDER_METADATA" != "true" ]]; then
-            clean_ds_store_tree "$volume" "$(basename "$volume") volume (.DS_Store)"
+            clean_ds_store_tree "$volume" "$(basename "$volume") volume, .DS_Store"
         fi
     done
     stop_section_spinner
@@ -288,7 +319,7 @@ clean_finder_metadata() {
     if [[ "$PROTECT_FINDER_METADATA" == "true" ]]; then
         return
     fi
-    clean_ds_store_tree "$HOME" "Home directory (.DS_Store)"
+    clean_ds_store_tree "$HOME" "Home directory, .DS_Store"
 }
 # macOS system caches and user-level leftovers.
 clean_macos_system_caches() {
@@ -367,7 +398,7 @@ clean_mail_downloads() {
     done
     if [[ $count -gt 0 ]]; then
         local cleaned_mb=$(echo "$cleaned_kb" | awk '{printf "%.1f", $1/1024}' || echo "0.0")
-        echo "  ${GREEN}${ICON_SUCCESS}${NC} Cleaned $count mail attachments (~${cleaned_mb}MB)"
+        echo "  ${GREEN}${ICON_SUCCESS}${NC} Cleaned $count mail attachments, about ${cleaned_mb}MB"
         note_activity
     fi
 }
@@ -396,9 +427,9 @@ clean_sandboxed_app_caches() {
     if [[ "$found_any" == "true" ]]; then
         local size_human=$(bytes_to_human "$((total_size * 1024))")
         if [[ "$DRY_RUN" == "true" ]]; then
-            echo -e "  ${YELLOW}${ICON_DRY_RUN}${NC} Sandboxed app caches ${YELLOW}($size_human dry)${NC}"
+            echo -e "  ${YELLOW}${ICON_DRY_RUN}${NC} Sandboxed app caches${NC}, ${YELLOW}$size_human dry${NC}"
         else
-            echo -e "  ${GREEN}${ICON_SUCCESS}${NC} Sandboxed app caches ${GREEN}($size_human)${NC}"
+            echo -e "  ${GREEN}${ICON_SUCCESS}${NC} Sandboxed app caches${NC}, ${GREEN}$size_human${NC}"
         fi
         ((files_cleaned += cleaned_count))
         ((total_size_cleaned += total_size))
@@ -426,15 +457,18 @@ process_container_cache() {
         found_any=true
         ((cleaned_count++))
         if [[ "$DRY_RUN" != "true" ]]; then
-            # Clean contents safely with local nullglob.
-            local _ng_state
-            _ng_state=$(shopt -p nullglob || true)
-            shopt -s nullglob
-            for item in "$cache_dir"/*; do
-                [[ -e "$item" ]] || continue
-                safe_remove "$item" true || true
-            done
-            eval "$_ng_state"
+            # For directories with many files, use find -delete for performance
+            if ! find "$cache_dir" -mindepth 1 -delete 2> /dev/null; then
+                # Fallback: try item-by-item if find fails
+                local _ng_state
+                _ng_state=$(shopt -p nullglob || true)
+                shopt -s nullglob
+                for item in "$cache_dir"/*; do
+                    [[ -e "$item" ]] || continue
+                    safe_remove "$item" true || true
+                done
+                eval "$_ng_state"
+            fi
         fi
     fi
 }
@@ -451,6 +485,12 @@ clean_browsers() {
     safe_clean ~/Library/Caches/company.thebrowser.Browser/* "Arc cache"
     safe_clean ~/Library/Caches/company.thebrowser.dia/* "Dia cache"
     safe_clean ~/Library/Caches/BraveSoftware/Brave-Browser/* "Brave cache"
+    # Yandex Browser.
+    safe_clean ~/Library/Caches/Yandex/YandexBrowser/* "Yandex cache"
+    safe_clean ~/Library/Application\ Support/Yandex/YandexBrowser/ShaderCache/* "Yandex shader cache"
+    safe_clean ~/Library/Application\ Support/Yandex/YandexBrowser/GrShaderCache/* "Yandex GR shader cache"
+    safe_clean ~/Library/Application\ Support/Yandex/YandexBrowser/GraphiteDawnCache/* "Yandex Dawn cache"
+    safe_clean ~/Library/Application\ Support/Yandex/YandexBrowser/*/GPUCache/* "Yandex GPU cache"
     local firefox_running=false
     if pgrep -x "Firefox" > /dev/null 2>&1; then
         firefox_running=true
@@ -543,10 +583,15 @@ clean_application_support_logs() {
                     ((cleaned_count++))
                     found_any=true
                     if [[ "$DRY_RUN" != "true" ]]; then
-                        for item in "$candidate"/*; do
-                            [[ -e "$item" ]] || continue
-                            safe_remove "$item" true > /dev/null 2>&1 || true
-                        done
+                        # For directories with many files, use find -delete for performance
+                        # This avoids shell expansion and individual safe_remove calls
+                        if ! find "$candidate" -mindepth 1 -delete 2> /dev/null; then
+                            # Fallback: try item-by-item if find fails
+                            for item in "$candidate"/*; do
+                                [[ -e "$item" ]] || continue
+                                safe_remove "$item" true > /dev/null 2>&1 || true
+                            done
+                        fi
                     fi
                 fi
             fi
@@ -567,10 +612,15 @@ clean_application_support_logs() {
                     ((cleaned_count++))
                     found_any=true
                     if [[ "$DRY_RUN" != "true" ]]; then
-                        for item in "$candidate"/*; do
-                            [[ -e "$item" ]] || continue
-                            safe_remove "$item" true > /dev/null 2>&1 || true
-                        done
+                        # For directories with many files, use find -delete for performance
+                        # This avoids shell expansion and individual safe_remove calls
+                        if ! find "$candidate" -mindepth 1 -delete 2> /dev/null; then
+                            # Fallback: try item-by-item if find fails
+                            for item in "$candidate"/*; do
+                                [[ -e "$item" ]] || continue
+                                safe_remove "$item" true > /dev/null 2>&1 || true
+                            done
+                        fi
                     fi
                 fi
             fi
@@ -581,9 +631,9 @@ clean_application_support_logs() {
     if [[ "$found_any" == "true" ]]; then
         local size_human=$(bytes_to_human "$((total_size * 1024))")
         if [[ "$DRY_RUN" == "true" ]]; then
-            echo -e "  ${YELLOW}${ICON_DRY_RUN}${NC} Application Support logs/caches ${YELLOW}($size_human dry)${NC}"
+            echo -e "  ${YELLOW}${ICON_DRY_RUN}${NC} Application Support logs/caches${NC}, ${YELLOW}$size_human dry${NC}"
         else
-            echo -e "  ${GREEN}${ICON_SUCCESS}${NC} Application Support logs/caches ${GREEN}($size_human)${NC}"
+            echo -e "  ${GREEN}${ICON_SUCCESS}${NC} Application Support logs/caches${NC}, ${GREEN}$size_human${NC}"
         fi
         ((files_cleaned += cleaned_count))
         ((total_size_cleaned += total_size))
@@ -598,7 +648,7 @@ check_ios_device_backups() {
     if [[ -d "$backup_dir" ]]; then
         local backup_kb=$(get_path_size_kb "$backup_dir")
         if [[ -n "${backup_kb:-}" && "$backup_kb" -gt 102400 ]]; then
-            local backup_human=$(command du -sh "$backup_dir" 2> /dev/null | awk '{print $1}')
+            local backup_human=$(command du -shP "$backup_dir" 2> /dev/null | awk '{print $1}')
             if [[ -n "$backup_human" ]]; then
                 note_activity
                 echo -e "  ${YELLOW}${ICON_WARNING}${NC} iOS backups: ${GREEN}${backup_human}${NC}${GRAY}, Path: $backup_dir${NC}"
