@@ -15,7 +15,7 @@ readonly MOLE_BASE_LOADED=1
 # ============================================================================
 readonly ESC=$'\033'
 readonly GREEN="${ESC}[0;32m"
-readonly BLUE="${ESC}[0;34m"
+readonly BLUE="${ESC}[1;34m"
 readonly CYAN="${ESC}[0;36m"
 readonly YELLOW="${ESC}[0;33m"
 readonly PURPLE="${ESC}[0;35m"
@@ -63,6 +63,8 @@ declare -a DEFAULT_WHITELIST_PATTERNS=(
     "$HOME/Library/Caches/ms-playwright*"
     "$HOME/.cache/huggingface*"
     "$HOME/.m2/repository/*"
+    "$HOME/.gradle/caches/*"
+    "$HOME/.gradle/daemon/*"
     "$HOME/.ollama/models/*"
     "$HOME/Library/Caches/com.nssurge.surge-mac/*"
     "$HOME/Library/Application Support/com.nssurge.surge-mac/*"
@@ -626,9 +628,12 @@ start_section_spinner() {
 # Stop spinner and clear the line
 # Usage: stop_section_spinner
 stop_section_spinner() {
+    # Always try to stop spinner (function handles empty PID gracefully)
     stop_inline_spinner 2> /dev/null || true
+    # Always clear line to handle edge cases where spinner output remains
+    # (e.g., spinner was stopped elsewhere but line not cleared)
     if [[ -t 1 ]]; then
-        echo -ne "\r\033[K" >&2 || true
+        printf "\r\033[2K" >&2 || true
     fi
 }
 
@@ -646,7 +651,7 @@ safe_clear_lines() {
     # Clear lines one by one (more reliable than multi-line sequences)
     local i
     for ((i = 0; i < lines; i++)); do
-        printf "\033[1A\r\033[K" > "$tty_device" 2> /dev/null || return 1
+        printf "\033[1A\r\033[2K" > "$tty_device" 2> /dev/null || return 1
     done
 
     return 0
@@ -660,7 +665,7 @@ safe_clear_line() {
     # Use centralized ANSI support check
     is_ansi_supported 2> /dev/null || return 1
 
-    printf "\r\033[K" > "$tty_device" 2> /dev/null || return 1
+    printf "\r\033[2K" > "$tty_device" 2> /dev/null || return 1
     return 0
 }
 
@@ -687,7 +692,7 @@ update_progress_if_needed() {
     if [[ $((current_time - last_time)) -ge $interval ]]; then
         # Update the spinner with progress
         stop_section_spinner
-        start_section_spinner "Scanning items... ($completed/$total)"
+        start_section_spinner "Scanning items... $completed/$total"
 
         # Update the last_update_time variable
         eval "$last_update_var=$current_time"
@@ -717,7 +722,7 @@ push_spinner_state() {
     fi
 
     MOLE_SPINNER_STACK+=("$current_state")
-    debug_log "Pushed spinner state: $current_state (stack depth: ${#MOLE_SPINNER_STACK[@]})"
+    debug_log "Pushed spinner state: $current_state, stack depth: ${#MOLE_SPINNER_STACK[@]}"
 }
 
 # Pop and restore spinner state from stack
@@ -730,7 +735,7 @@ pop_spinner_state() {
 
     # Stack depth safety check
     if [[ ${#MOLE_SPINNER_STACK[@]} -gt 10 ]]; then
-        debug_log "Warning: Spinner stack depth excessive (${#MOLE_SPINNER_STACK[@]}), possible leak"
+        debug_log "Warning: Spinner stack depth excessive, ${#MOLE_SPINNER_STACK[@]}, possible leak"
     fi
 
     local last_idx=$((${#MOLE_SPINNER_STACK[@]} - 1))
@@ -745,7 +750,7 @@ pop_spinner_state() {
     done
     MOLE_SPINNER_STACK=("${new_stack[@]}")
 
-    debug_log "Popped spinner state: $state (remaining depth: ${#MOLE_SPINNER_STACK[@]})"
+    debug_log "Popped spinner state: $state, remaining depth: ${#MOLE_SPINNER_STACK[@]}"
 
     # Restore state if needed
     if [[ "$state" == running:* ]]; then
@@ -822,7 +827,7 @@ get_terminal_info() {
     local info="Terminal: ${TERM:-unknown}"
 
     if is_ansi_supported; then
-        info+=" (ANSI supported)"
+        info+=", ANSI supported"
 
         if command -v tput > /dev/null 2>&1; then
             local cols=$(tput cols 2> /dev/null || echo "?")
@@ -831,7 +836,7 @@ get_terminal_info() {
             info+=" ${cols}x${lines}, ${colors} colors"
         fi
     else
-        info+=" (ANSI not supported)"
+        info+=", ANSI not supported"
     fi
 
     echo "$info"
@@ -852,11 +857,11 @@ validate_terminal_environment() {
     # Check if running in a known problematic terminal
     case "${TERM:-}" in
         dumb)
-            log_warning "Running in 'dumb' terminal - limited functionality"
+            log_warning "Running in 'dumb' terminal, limited functionality"
             ((warnings++))
             ;;
         unknown)
-            log_warning "Terminal type unknown - may have display issues"
+            log_warning "Terminal type unknown, may have display issues"
             ((warnings++))
             ;;
     esac
@@ -865,7 +870,7 @@ validate_terminal_environment() {
     if command -v tput > /dev/null 2>&1; then
         local cols=$(tput cols 2> /dev/null || echo "80")
         if [[ "$cols" -lt 60 ]]; then
-            log_warning "Terminal width ($cols cols) is narrow - output may wrap"
+            log_warning "Terminal width, $cols cols, is narrow, output may wrap"
             ((warnings++))
         fi
     fi
