@@ -72,12 +72,20 @@ decode_file_list() {
 # Note: find_app_files() and calculate_total_size() are in lib/core/common.sh.
 
 # Stop Launch Agents/Daemons for an app.
+# Security: bundle_id is validated to be reverse-DNS format before use in find patterns
 stop_launch_services() {
     local bundle_id="$1"
     local has_system_files="${2:-false}"
 
     [[ -z "$bundle_id" || "$bundle_id" == "unknown" ]] && return 0
 
+    # Validate bundle_id format: must be reverse-DNS style (e.g., com.example.app)
+    # This prevents glob injection attacks if bundle_id contains special characters
+    if [[ ! "$bundle_id" =~ ^[a-zA-Z0-9][-a-zA-Z0-9]*(\.[a-zA-Z0-9][-a-zA-Z0-9]*)+$ ]]; then
+        debug_log "Invalid bundle_id format for LaunchAgent search: $bundle_id"
+        return 0
+    fi
+
     if [[ -d ~/Library/LaunchAgents ]]; then
         while IFS= read -r -d '' plist; do
             launchctl unload "$plist" 2> /dev/null || true
@@ -135,6 +143,7 @@ remove_login_item() {
 }
 
 # Remove files (handles symlinks, optional sudo).
+# Security: All paths pass validate_path_for_deletion() before any deletion.
 remove_file_list() {
     local file_list="$1"
     local use_sudo="${2:-false}"
@@ -148,11 +157,7 @@ remove_file_list() {
         fi
 
         if [[ -L "$file" ]]; then
-            if [[ "$use_sudo" == "true" ]]; then
-                sudo rm "$file" 2> /dev/null && ((++count)) || true
-            else
-                rm "$file" 2> /dev/null && ((++count)) || true
-            fi
+            safe_remove_symlink "$file" "$use_sudo" && ((++count)) || true
         else
             if [[ "$use_sudo" == "true" ]]; then
                 safe_sudo_remove "$file" && ((++count)) || true
@@ -179,7 +184,16 @@ batch_uninstall_applications() {
     old_trap_int=$(trap -p INT)
     old_trap_term=$(trap -p TERM)
 
+    _cleanup_sudo_keepalive() {
+        if [[ -n "${sudo_keepalive_pid:-}" ]]; then
+            kill "$sudo_keepalive_pid" 2> /dev/null || true
+            wait "$sudo_keepalive_pid" 2> /dev/null || true
+            sudo_keepalive_pid=""
+        fi
+    }
+
     _restore_uninstall_traps() {
+        _cleanup_sudo_keepalive
         if [[ -n "$old_trap_int" ]]; then
             eval "$old_trap_int"
         else
@@ -192,8 +206,8 @@ batch_uninstall_applications() {
         fi
     }
 
-    # Trap to clean up spinner and uninstall mode on interrupt
-    trap 'stop_inline_spinner 2>/dev/null; unset MOLE_UNINSTALL_MODE; echo ""; _restore_uninstall_traps; return 130' INT TERM
+    # Trap to clean up spinner, sudo keepalive, and uninstall mode on interrupt
+    trap 'stop_inline_spinner 2>/dev/null; _cleanup_sudo_keepalive; unset MOLE_UNINSTALL_MODE; echo ""; _restore_uninstall_traps; return 130' INT TERM
 
     # Pre-scan: running apps, sudo needs, size.
     local -a running_apps=()
@@ -244,20 +258,28 @@ batch_uninstall_applications() {
             needs_sudo=true
         fi
 
-        # Size estimate includes related and system files.
-        local app_size_kb=$(get_path_size_kb "$app_path")
-        local related_files=$(find_app_files "$bundle_id" "$app_name")
-        local related_size_kb=$(calculate_total_size "$related_files")
+        local app_size_kb=$(get_path_size_kb "$app_path" || echo "0")
+        local related_files=$(find_app_files "$bundle_id" "$app_name" || true)
+        local diag_user
+        diag_user=$(get_diagnostic_report_paths_for_app "$app_path" "$app_name" "$HOME/Library/Logs/DiagnosticReports" || true)
+        [[ -n "$diag_user" ]] && related_files=$(
+            [[ -n "$related_files" ]] && echo "$related_files"
+            echo "$diag_user"
+        )
+        local related_size_kb=$(calculate_total_size "$related_files" || echo "0")
         # system_files is a newline-separated string, not an array.
         # shellcheck disable=SC2178,SC2128
-        local system_files=$(find_app_system_files "$bundle_id" "$app_name")
+        local system_files=$(find_app_system_files "$bundle_id" "$app_name" || true)
+        local diag_system
+        diag_system=$(get_diagnostic_report_paths_for_app "$app_path" "$app_name" "/Library/Logs/DiagnosticReports" || true)
         # shellcheck disable=SC2128
-        local system_size_kb=$(calculate_total_size "$system_files")
-        local total_kb=$((app_size_kb + related_size_kb + system_size_kb))
-        ((total_estimated_size += total_kb))
+        local system_size_kb=$(calculate_total_size "$system_files" || echo "0")
+        local diag_system_size_kb=$(calculate_total_size "$diag_system" || echo "0")
+        local total_kb=$((app_size_kb + related_size_kb + system_size_kb + diag_system_size_kb))
+        ((total_estimated_size += total_kb)) || true
 
         # shellcheck disable=SC2128
-        if [[ -n "$system_files" ]]; then
+        if [[ -n "$system_files" || -n "$diag_system" ]]; then
             needs_sudo=true
         fi
 
@@ -267,16 +289,18 @@ batch_uninstall_applications() {
 
         # Check for sensitive user data once.
         local has_sensitive_data="false"
-        if has_sensitive_data "$related_files"; then
+        if has_sensitive_data "$related_files" 2> /dev/null; then
             has_sensitive_data="true"
         fi
 
         # Store details for later use (base64 keeps lists on one line).
         local encoded_files
-        encoded_files=$(printf '%s' "$related_files" | base64 | tr -d '\n')
+        encoded_files=$(printf '%s' "$related_files" | base64 | tr -d '\n' || echo "")
         local encoded_system_files
-        encoded_system_files=$(printf '%s' "$system_files" | base64 | tr -d '\n')
-        app_details+=("$app_name|$app_path|$bundle_id|$total_kb|$encoded_files|$encoded_system_files|$has_sensitive_data|$needs_sudo|$is_brew_cask|$cask_name")
+        encoded_system_files=$(printf '%s' "$system_files" | base64 | tr -d '\n' || echo "")
+        local encoded_diag_system
+        encoded_diag_system=$(printf '%s' "$diag_system" | base64 | tr -d '\n' || echo "")
+        app_details+=("$app_name|$app_path|$bundle_id|$total_kb|$encoded_files|$encoded_system_files|$has_sensitive_data|$needs_sudo|$is_brew_cask|$cask_name|$encoded_diag_system")
     done
     if [[ -t 1 ]]; then stop_inline_spinner; fi
 
@@ -286,63 +310,51 @@ batch_uninstall_applications() {
     echo -e "${PURPLE_BOLD}Files to be removed:${NC}"
     echo ""
 
-    # Warn if user data is detected.
-    local has_user_data=false
+    # Warn if brew cask apps are present.
+    local has_brew_cask=false
     for detail in "${app_details[@]}"; do
-        IFS='|' read -r _ _ _ _ _ _ has_sensitive_data <<< "$detail"
-        if [[ "$has_sensitive_data" == "true" ]]; then
-            has_user_data=true
-            break
-        fi
+        IFS='|' read -r _ _ _ _ _ _ _ _ is_brew_cask_flag _ <<< "$detail"
+        [[ "$is_brew_cask_flag" == "true" ]] && has_brew_cask=true
     done
 
-    if [[ "$has_user_data" == "true" ]]; then
-        echo -e "${GRAY}${ICON_WARNING}${NC} ${YELLOW}Note: Some apps contain user configurations/themes${NC}"
+    if [[ "$has_brew_cask" == "true" ]]; then
+        echo -e "${GRAY}${ICON_WARNING}${NC} ${YELLOW}Homebrew apps will be fully cleaned (--zap: removes configs & data)${NC}"
         echo ""
     fi
 
     for detail in "${app_details[@]}"; do
-        IFS='|' read -r app_name app_path bundle_id total_kb encoded_files encoded_system_files has_sensitive_data needs_sudo_flag is_brew_cask cask_name <<< "$detail"
+        IFS='|' read -r app_name app_path bundle_id total_kb encoded_files encoded_system_files has_sensitive_data needs_sudo_flag is_brew_cask cask_name encoded_diag_system <<< "$detail"
         local app_size_display=$(bytes_to_human "$((total_kb * 1024))")
 
         local brew_tag=""
         [[ "$is_brew_cask" == "true" ]] && brew_tag=" ${CYAN}[Brew]${NC}"
-        echo -e "${BLUE}${ICON_CONFIRM}${NC} ${app_name}${brew_tag} ${GRAY}(${app_size_display})${NC}"
+        echo -e "${BLUE}${ICON_CONFIRM}${NC} ${app_name}${brew_tag} ${GRAY}, ${app_size_display}${NC}"
 
         # Show detailed file list for ALL apps (brew casks leave user data behind)
         local related_files=$(decode_file_list "$encoded_files" "$app_name")
         local system_files=$(decode_file_list "$encoded_system_files" "$app_name")
+        local diag_system_display
+        diag_system_display=$(decode_file_list "$encoded_diag_system" "$app_name")
+        [[ -n "$diag_system_display" ]] && system_files=$(
+            [[ -n "$system_files" ]] && echo "$system_files"
+            echo "$diag_system_display"
+        )
 
         echo -e "  ${GREEN}${ICON_SUCCESS}${NC} ${app_path/$HOME/~}"
 
-        # Show related files (limit to 5).
-        local file_count=0
-        local max_files=5
+        # Show all related files so users can fully review before deletion.
         while IFS= read -r file; do
             if [[ -n "$file" && -e "$file" ]]; then
-                if [[ $file_count -lt $max_files ]]; then
-                    echo -e "  ${GREEN}${ICON_SUCCESS}${NC} ${file/$HOME/~}"
-                fi
-                ((file_count++))
+                echo -e "  ${GREEN}${ICON_SUCCESS}${NC} ${file/$HOME/~}"
             fi
         done <<< "$related_files"
 
-        # Show system files (limit to 5).
-        local sys_file_count=0
+        # Show all system files so users can fully review before deletion.
         while IFS= read -r file; do
             if [[ -n "$file" && -e "$file" ]]; then
-                if [[ $sys_file_count -lt $max_files ]]; then
-                    echo -e "  ${BLUE}${ICON_WARNING}${NC} System: $file"
-                fi
-                ((sys_file_count++))
+                echo -e "  ${BLUE}${ICON_WARNING}${NC} System: $file"
             fi
         done <<< "$system_files"
-
-        local total_hidden=$((file_count > max_files ? file_count - max_files : 0))
-        ((total_hidden += sys_file_count > max_files ? sys_file_count - max_files : 0))
-        if [[ $total_hidden -gt 0 ]]; then
-            echo -e "  ${GRAY}  ... and ${total_hidden} more files${NC}"
-        fi
     done
 
     # Confirmation before requesting sudo.
@@ -352,7 +364,7 @@ batch_uninstall_applications() {
 
     echo ""
     local removal_note="Remove ${app_total} ${app_text}"
-    [[ -n "$size_display" ]] && removal_note+=" (${size_display})"
+    [[ -n "$size_display" ]] && removal_note+=", ${size_display}"
     if [[ ${#running_apps[@]} -gt 0 ]]; then
         removal_note+=" ${YELLOW}[Running]${NC}"
     fi
@@ -413,10 +425,12 @@ batch_uninstall_applications() {
     local current_index=0
     for detail in "${app_details[@]}"; do
         ((current_index++))
-        IFS='|' read -r app_name app_path bundle_id total_kb encoded_files encoded_system_files has_sensitive_data needs_sudo is_brew_cask cask_name <<< "$detail"
+        IFS='|' read -r app_name app_path bundle_id total_kb encoded_files encoded_system_files has_sensitive_data needs_sudo is_brew_cask cask_name encoded_diag_system <<< "$detail"
         local related_files=$(decode_file_list "$encoded_files" "$app_name")
         local system_files=$(decode_file_list "$encoded_system_files" "$app_name")
+        local diag_system=$(decode_file_list "$encoded_diag_system" "$app_name")
         local reason=""
+        local suggestion=""
 
         # Show progress for current app
         local brew_tag=""
@@ -455,22 +469,58 @@ batch_uninstall_applications() {
                 else
                     # Fallback to manual removal if brew fails
                     if [[ "$needs_sudo" == true ]]; then
-                        safe_sudo_remove "$app_path" || reason="remove failed"
+                        if ! safe_sudo_remove "$app_path"; then
+                            reason="brew failed, manual removal failed"
+                        fi
                     else
-                        safe_remove "$app_path" true || reason="remove failed"
+                        if ! safe_remove "$app_path" true; then
+                            reason="brew failed, manual removal failed"
+                        fi
                     fi
                 fi
             elif [[ "$needs_sudo" == true ]]; then
-                if ! safe_sudo_remove "$app_path"; then
-                    local app_owner=$(get_file_owner "$app_path")
-                    if [[ -n "$app_owner" && "$app_owner" != "$current_user" && "$app_owner" != "root" ]]; then
-                        reason="owned by $app_owner"
+                if [[ -L "$app_path" ]]; then
+                    local link_target
+                    link_target=$(readlink "$app_path" 2> /dev/null)
+                    if [[ -n "$link_target" ]]; then
+                        local resolved_target="$link_target"
+                        if [[ "$link_target" != /* ]]; then
+                            local link_dir
+                            link_dir=$(dirname "$app_path")
+                            resolved_target=$(cd "$link_dir" 2> /dev/null && cd "$(dirname "$link_target")" 2> /dev/null && pwd)/$(basename "$link_target") 2> /dev/null || echo ""
+                        fi
+                        case "$resolved_target" in
+                            /System/* | /usr/bin/* | /usr/lib/* | /bin/* | /sbin/* | /private/etc/*)
+                                reason="protected system symlink, cannot remove"
+                                ;;
+                            *)
+                                if ! safe_remove_symlink "$app_path" "true"; then
+                                    reason="failed to remove symlink"
+                                fi
+                                ;;
+                        esac
                     else
-                        reason="permission denied"
+                        if ! safe_remove_symlink "$app_path" "true"; then
+                            reason="failed to remove symlink"
+                        fi
+                    fi
+                else
+                    local ret=0
+                    safe_sudo_remove "$app_path" || ret=$?
+                    if [[ $ret -ne 0 ]]; then
+                        local diagnosis
+                        diagnosis=$(diagnose_removal_failure "$ret" "$app_name")
+                        IFS='|' read -r reason suggestion <<< "$diagnosis"
                     fi
                 fi
             else
-                safe_remove "$app_path" true || reason="remove failed"
+                if ! safe_remove "$app_path" true; then
+                    if [[ ! -w "$(dirname "$app_path")" ]]; then
+                        reason="parent directory not writable"
+                    else
+                        reason="remove failed, check permissions"
+                    fi
+                fi
             fi
         fi
 
@@ -478,11 +528,17 @@ batch_uninstall_applications() {
         if [[ -z "$reason" ]]; then
             remove_file_list "$related_files" "false" > /dev/null
 
-            # If brew successfully uninstalled the cask, avoid deleting
-            # system-level files Mole discovered. Brew manages its own
-            # receipts/symlinks and we don't want to fight it.
-            if [[ "$used_brew_successfully" != "true" ]]; then
-                remove_file_list "$system_files" "true" > /dev/null
+            if [[ "$used_brew_successfully" == "true" ]]; then
+                remove_file_list "$diag_system" "true" > /dev/null
+            else
+                local system_all="$system_files"
+                if [[ -n "$diag_system" ]]; then
+                    if [[ -n "$system_all" ]]; then
+                        system_all+=$'\n'
+                    fi
+                    system_all+="$diag_system"
+                fi
+                remove_file_list "$system_all" "true" > /dev/null
             fi
 
             # Clean up macOS defaults (preference domains).
@@ -492,8 +548,14 @@ batch_uninstall_applications() {
                 fi
 
                 # ByHost preferences (machine-specific).
-                if [[ -d ~/Library/Preferences/ByHost ]]; then
-                    find ~/Library/Preferences/ByHost -maxdepth 1 -name "${bundle_id}.*.plist" -delete 2> /dev/null || true
+                if [[ -d "$HOME/Library/Preferences/ByHost" ]]; then
+                    if [[ "$bundle_id" =~ ^[A-Za-z0-9._-]+$ ]]; then
+                        while IFS= read -r -d '' plist_file; do
+                            safe_remove "$plist_file" true > /dev/null || true
+                        done < <(command find "$HOME/Library/Preferences/ByHost" -maxdepth 1 -type f -name "${bundle_id}.*.plist" -print0 2> /dev/null || true)
+                    else
+                        debug_log "Skipping ByHost cleanup, invalid bundle id: $bundle_id"
+                    fi
                 fi
             fi
 
@@ -511,19 +573,21 @@ batch_uninstall_applications() {
             [[ "$used_brew_successfully" == "true" ]] && ((brew_apps_removed++))
             ((files_cleaned++))
             ((total_items++))
-            success_items+=("$app_name")
+            success_items+=("$app_path")
         else
-            # Show failure
             if [[ -t 1 ]]; then
                 if [[ ${#app_details[@]} -gt 1 ]]; then
-                    echo -e "${ICON_ERROR} [$current_index/${#app_details[@]}] ${app_name} ${GRAY}($reason)${NC}"
+                    echo -e "${ICON_ERROR} [$current_index/${#app_details[@]}] ${app_name} ${GRAY}, $reason${NC}"
                 else
                     echo -e "${ICON_ERROR} ${app_name} failed: $reason"
                 fi
+                if [[ -n "${suggestion:-}" ]]; then
+                    echo -e "${GRAY}   → ${suggestion}${NC}"
+                fi
             fi
 
             ((failed_count++))
-            failed_items+=("$app_name:$reason")
+            failed_items+=("$app_name:$reason:${suggestion:-}")
         fi
     done
 
@@ -535,7 +599,6 @@ batch_uninstall_applications() {
     local -a summary_details=()
 
     if [[ $success_count -gt 0 ]]; then
-        local success_list="${success_items[*]}"
         local success_text="app"
         [[ $success_count -gt 1 ]] && success_text="apps"
         local success_line="Removed ${success_count} ${success_text}"
@@ -544,13 +607,15 @@ batch_uninstall_applications() {
         fi
 
         # Format app list with max 3 per line.
-        if [[ -n "$success_list" ]]; then
+        if [[ ${#success_items[@]} -gt 0 ]]; then
             local idx=0
             local is_first_line=true
             local current_line=""
 
-            for app_name in "${success_items[@]}"; do
-                local display_item="${GREEN}${app_name}${NC}"
+            for success_path in "${success_items[@]}"; do
+                local display_name
+                display_name=$(basename "$success_path" .app)
+                local display_item="${GREEN}${display_name}${NC}"
 
                 if ((idx % 3 == 0)); then
                     if [[ -n "$current_line" ]]; then
@@ -586,17 +651,32 @@ batch_uninstall_applications() {
         local failed_list="${failed_names[*]}"
 
         local reason_summary="could not be removed"
+        local suggestion_text=""
         if [[ $failed_count -eq 1 ]]; then
-            local first_reason=${failed_items[0]#*:}
+            # Extract reason and suggestion from format: app:reason:suggestion
+            local item="${failed_items[0]}"
+            local without_app="${item#*:}"
+            local first_reason="${without_app%%:*}"
+            local first_suggestion="${without_app#*:}"
+
+            # If suggestion is same as reason, there was no suggestion part
+            # Also check if suggestion is empty
+            if [[ "$first_suggestion" != "$first_reason" && -n "$first_suggestion" ]]; then
+                suggestion_text="${GRAY}   → ${first_suggestion}${NC}"
+            fi
+
             case "$first_reason" in
                 still*running*) reason_summary="is still running" ;;
                 remove*failed*) reason_summary="could not be removed" ;;
                 permission*denied*) reason_summary="permission denied" ;;
-                owned*by*) reason_summary="$first_reason (try with sudo)" ;;
+                owned*by*) reason_summary="$first_reason, try with sudo" ;;
                 *) reason_summary="$first_reason" ;;
             esac
         fi
         summary_details+=("Failed: ${RED}${failed_list}${NC} ${reason_summary}")
+        if [[ -n "$suggestion_text" ]]; then
+            summary_details+=("$suggestion_text")
+        fi
     fi
 
     if [[ $success_count -eq 0 && $failed_count -eq 0 ]]; then
@@ -636,38 +716,15 @@ batch_uninstall_applications() {
     fi
 
     # Clean up Dock entries for uninstalled apps.
-    if [[ $success_count -gt 0 ]]; then
-        local -a removed_paths=()
-        for detail in "${app_details[@]}"; do
-            IFS='|' read -r app_name app_path _ _ _ _ <<< "$detail"
-            for success_name in "${success_items[@]}"; do
-                if [[ "$success_name" == "$app_name" ]]; then
-                    removed_paths+=("$app_path")
-                    break
-                fi
-            done
-        done
-        if [[ ${#removed_paths[@]} -gt 0 ]]; then
-            remove_apps_from_dock "${removed_paths[@]}" 2> /dev/null || true
-        fi
+    if [[ $success_count -gt 0 && ${#success_items[@]} -gt 0 ]]; then
+        remove_apps_from_dock "${success_items[@]}" 2> /dev/null || true
     fi
 
-    # Clean up sudo keepalive if it was started.
-    if [[ -n "${sudo_keepalive_pid:-}" ]]; then
-        kill "$sudo_keepalive_pid" 2> /dev/null || true
-        wait "$sudo_keepalive_pid" 2> /dev/null || true
-        sudo_keepalive_pid=""
-    fi
+    _cleanup_sudo_keepalive
 
     # Disable uninstall mode
     unset MOLE_UNINSTALL_MODE
 
-    # Invalidate cache if any apps were successfully uninstalled.
-    if [[ $success_count -gt 0 ]]; then
-        local cache_file="$HOME/.cache/mole/app_scan_cache"
-        rm -f "$cache_file" 2> /dev/null || true
-    fi
-
     _restore_uninstall_traps
     unset -f _restore_uninstall_traps
 
